@@ -3,6 +3,7 @@ import gettext
 import gi
 import locale
 import os
+import psutil
 import setproctitle
 import subprocess
 import xapp.os
@@ -34,7 +35,25 @@ class GtkStatusIcon(Gtk.StatusIcon):
     def set_icon_name(self, icon_name):
         self.set_from_icon_name(icon_name)
 
+class MonitoredProcess():
+    def __init__(self, name, cmdline, description, is_binary=False):
+        self.name = name
+        self.cmdline = cmdline
+        self.description = description
 
+        self.is_binary = is_binary
+
+    def is_running(self):
+        for p in psutil.process_iter():
+            try:
+                if self.is_binary:
+                    if p.name() == self.cmdline:
+                        return True
+                elif self.cmdline in ' '.join(p.cmdline()):
+                    return True
+            except:
+                continue
+        return False
 
 class MyApplication(Gtk.Application):
     # Main initialization routine
@@ -67,6 +86,13 @@ class MyApplication(Gtk.Application):
             self.status_icon.connect("popup-menu", self.on_gtk_statusicon_popup)
         self.status_icon.set_visible(False)
 
+        # Monitor icon
+        self.monitor_icon = XApp.StatusIcon()
+        self.monitor_icon.set_name("process-monitor")
+        self.monitor_icon.set_visible(False)
+        self.monitoring_process = None
+        self.monitor_source_id = None
+
     def on_statusicon_activated(self, icon, button, time):
         if button == Gdk.BUTTON_PRIMARY:
             GLib.spawn_async(["/usr/bin/mintreport"])
@@ -92,6 +118,9 @@ class MyApplication(Gtk.Application):
             # Auto-refresh
             if self.settings.get_boolean("autorefresh"):
                 GLib.timeout_add_seconds(self.settings.get_int("autorefresh-seconds"), self.load_info)
+            # Auto-monitor
+            if self.settings.get_boolean("automonitor"):
+                GLib.timeout_add_seconds(self.settings.get_int("automonitor-seconds"), self.monitor)
         else:
             print("Already running!")
 
@@ -120,6 +149,36 @@ class MyApplication(Gtk.Application):
 
         return True
 
+    def monitor(self):
+        if self.monitoring_process != None:
+            return GLib.SOURCE_CONTINUE
+        processes = []
+        processes.append(MonitoredProcess(_("System Snapshots"), "timeshift", _("A Timeshift system snapshot is being created."), is_binary=True))
+        processes.append(MonitoredProcess(_("Automatic Updates"), "/usr/lib/linuxmint/mintUpdate/automatic_upgrades.py", _("Automatic updates are being installed.")))
+        self.monitor_icon.set_visible(False)
+        for process in processes:
+            if process.is_running():
+                # A process is found running!
+                # Show a tray icon
+                self.monitoring_process = process
+                self.monitor_icon.set_visible(True)
+                self.monitor_icon.set_icon_name("system-run-symbolic")
+                tooltip = "<b>%s</b>\n%s" % (process.name, process.description)
+                self.monitor_icon.set_tooltip_text(tooltip)
+                # Start a clean up thread to hide the tray when it finishes
+                self.monitor_source_id = GLib.timeout_add_seconds(2, self.clean_up)
+        return GLib.SOURCE_CONTINUE
+
+    def clean_up(self):
+        if self.monitoring_process == None:
+            return GLib.SOURCE_REMOVE
+        if not self.monitoring_process.is_running():
+            # The process is finished, hide the tray
+            self.monitoring_process = None
+            self.monitor_icon.set_visible(False)
+            GLib.source_remove(self.monitor_source_id)
+        return GLib.SOURCE_CONTINUE
+
 if __name__ == "__main__":
     if ((not xapp.os.is_live_session()) and (not xapp.os.is_guest_session())):
         application = MyApplication("com.linuxmint.reports-tray", Gio.ApplicationFlags.FLAGS_NONE)
